# SkitterSchema
This is an auxiliary package to SkitterCrawler, where we convert the data extracted from the internet,
for example the data retrieved from Twitter's API, to Python classes which interface directly with an SQL database.
This is done with SQLAlchemy's Object Relational Mapping (ORM).

**TODO**:
- get user mentions from description
- add place
- add weight to edges
